@@ -61,7 +61,7 @@ def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=
     list_cls_ini = None
     
     if (enable_cls_opt):
-    
+        print("----------- INICIO enable_cls_opt = True ---------------------")
         #list_cls_ini = ['Z_NOTA_M_T_MENOS_1', 'Z_NOTA_C_T_MENOS_1', 'EXTRA_EDAD_T_MENOS_1']+hd.get_bool_columns(X_train)
         list_cls_ini = cls_ini_opt + hd.get_bool_columns(X_train)
         
@@ -129,17 +129,23 @@ def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=
         args["X_test"]=X_test[list_cls_ini]
         args["url"]=url
         
+        print("----------- FIN enable_cls_opt = True ---------------------")
+        
 
    
     model ,  y_prob_uno_train, y_prob_uno_test    = l.modelar(**args)
     
+    kpis_train = generar_reporte(model,y_prob_uno_train,X_train,y_train,None,None,print_consola)
+
+    kpis_test = generar_reporte(model,y_prob_uno_test,X_test,y_test,None,url,print_consola)
+    
 
     umbral_opt=0
     kpis_opt = (0,0,0,0,0)
     
     if enable_umbral_opt:
         umbral_opt = g.get_opt_threshold(y_test,y_prob_uno_test)   
-        kpis_opt = generar_reporte(model,y_prob_uno_test,X_test,y_test,umbral_opt,url,print_consola)
+        kpis_opt = generar_reporte(model,y_prob_uno_test,X_test,y_test,umbral_opt,None,print_consola)
     
     print("Time elapsed: ", time.time() - start)
     
